# Manage Workspace Access
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/manage-workspace-access#overview)
  * [Workspace Access Options](https://help.sap.com/docs/leanix/ea/manage-workspace-access#workspace-access-options)
  * [Invitation-Based Access for SSO Workspaces](https://help.sap.com/docs/leanix/ea/manage-workspace-access#invitation-based-access-for-sso-workspaces)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/manage-workspace-access#related-resources)


Configure secure workspace access for single and multi-workspace environments through flexible access options using direct URLs, base URLs, workspace chooser, and invitation-only settings
